/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2020 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************

-------------------------- END-OF-HEADER -----------------------------
File    : OS_Mutexes.c
Purpose : embOS sample program demonstrating the usage of mutexes.
*/

#include "cmsis_os.h"
#include <stdio.h>

// Function prototypes for a Threads
static void HPTask(void const* pContext);
static void LPTask(void const* pContext);

// Thread definitions:  Routine, Priority,         #Instances, Stack size
osThreadDef            (HPTask,  osPriorityHigh,   1,          0);
osThreadDef            (LPTask,  osPriorityNormal, 1,          0);

// Mutex definition
osMutexDef             (Mutex);

// Handle to mutex for subsequent usage
osMutexId              MutexHandle;

/*********************************************************************
*
*       _Write()
*/
static void _Write(char const* s) {
  osMutexWait(MutexHandle, osWaitForever);
  puts(s);
  osMutexRelease(MutexHandle);
}

/*********************************************************************
*
*       HPTask()
*/
static void HPTask(void const* arg) {
  while (1) {
    _Write("HPTask\n");
    osDelay((uint32_t)arg);
  }
}

/*********************************************************************
*
*       LPTask()
*/
static void LPTask(void const* arg) {
  while (1) {
    _Write("LPTask\n");
    osDelay((uint32_t)arg);
  }
}

/*********************************************************************
*
*       main()
*/
int main(void) {
  osKernelInitialize();                          // Initialize embOS and required hardware
  osThreadCreate(osThread(HPTask), (void*) 50);  // Create HPTask
  osThreadCreate(osThread(LPTask), (void*)200);  // Create LPTask
  MutexHandle = osMutexCreate(osMutex(Mutex));   // Create Mutex
  osKernelStart();                               // Start embOS
  return 0;
}

/*************************** End of file ****************************/
