/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2020 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************

-------------------------- END-OF-HEADER -----------------------------
File    : OS_Mutexes.c
Purpose : embOS sample program demonstrating the usage of mutexes.
*/

#include "cmsis_os2.h"
#include <stdio.h>

// Attributes structure for threads:      Name,      Attribute_Bits,   TCB,  TCB size,  Stack, Stack size,  Priority,       TZ module, Reserved
static const osThreadAttr_t HPTaskAttr = {"HP Task", osThreadDetached, NULL, 0,         NULL,  0,           osPriorityHigh, 0,         0};
static const osThreadAttr_t LPTaskAttr = {"LP Task", osThreadDetached, NULL, 0,         NULL,  0,           osPriorityLow,  0,         0};

// Attributes structure for mutexes:      Name,    Attribute_Bits,   MCB,  MCB size
static const osMutexAttr_t  MutexAttr  = {"Mutex", 0,                NULL, 0};

// Handle to mutex for subsequent usage
osMutexId_t                 MutexHandle;

/*********************************************************************
*
*       _Write()
*/
static void _Write(char const* s) {
  osMutexAcquire(MutexHandle, osWaitForever);
  puts(s);
  osMutexRelease(MutexHandle);
}

/*********************************************************************
*
*       HPTask()
*/
static void HPTask(void* arg) {
  while (1) {
    _Write("HPTask\n");
    osDelay((uint32_t)arg);
  }
}

/*********************************************************************
*
*       LPTask()
*/
static void LPTask(void* arg) {
  while (1) {
    _Write("LPTask\n");
    osDelay((uint32_t)arg);
  }
}

/*********************************************************************
*
*       main()
*/
int main(void) {
  osKernelInitialize();                           // Initialize embOS and  required hardware
  osThreadNew(&HPTask, (void*) 50, &HPTaskAttr);  // Create HPTask
  osThreadNew(&LPTask, (void*)200, &LPTaskAttr);  // Create LPTask
  MutexHandle = osMutexNew(&MutexAttr);           // Create Mutex
  osKernelStart();                                // Start embOS
  return 0;
}

/*************************** End of file ****************************/
