/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2020 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************

-------------------------- END-OF-HEADER -----------------------------
File    : OS_Start2Tasks_CMSIS.c
Purpose : embOS CMSIS-RTOS API sample program running two simple tasks.
*/

#include "cmsis_os.h"

// Function prototypes for a Threads
static void HPTask(void const* pContext);
static void LPTask(void const* pContext);

// Thread definitions:  Routine, Priority,         #Instances, Stack size
osThreadDef            (HPTask,  osPriorityHigh,   1,          0);
osThreadDef            (LPTask,  osPriorityNormal, 1,          0);

/*********************************************************************
*
*       HPTask()
*/
static void HPTask(void const* pContext) {
  while (1) {
    osDelay((uint32_t)pContext);
  }
}

/*********************************************************************
*
*       LPTask()
*/
static void LPTask(void const* pContext) {
  while (1) {
    osDelay((uint32_t)pContext);
  }
}

/*********************************************************************
*
*       main()
*/
int main(void) {
  osKernelInitialize();                          // Initialize embOS and required hardware
  osThreadCreate(osThread(HPTask), (void*) 50);  // Create HPTask
  osThreadCreate(osThread(LPTask), (void*)200);  // Create LPTask
  osKernelStart();                               // Start embOS
  return 0;
}

/*************************** End of file ****************************/
