/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2020 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************

-------------------------- END-OF-HEADER -----------------------------
File    : OS_Start2Tasks_CMSIS2.c
Purpose : embOS CMSIS-RTOS2 API sample program running two simple tasks.
*/

#include "cmsis_os2.h"

// Attributes structure for threads:      Name,      Attribute_Bits,   TCB,  TCB size, Stack, Stack size, Priority,       TZ module, Reserved
static const osThreadAttr_t HPTaskAttr = {"HP Task", osThreadDetached, NULL, 0,        NULL,  0,          osPriorityHigh, 0,         0};
static const osThreadAttr_t LPTaskAttr = {"LP Task", osThreadDetached, NULL, 0,        NULL,  0,          osPriorityLow,  0,         0};

/*********************************************************************
*
*       HPTask()
*/
static void HPTask(void* pContext) {
  while (1) {
    osDelay((uint32_t)pContext);
  }
}

/*********************************************************************
*
*       LPTask()
*/
static void LPTask(void* pContext) {
  while (1) {
    osDelay((uint32_t)pContext);
  }
}

/*********************************************************************
*
*       main()
*/
int main(void) {
  osKernelInitialize();                           // Initialize embOS and required hardware
  osThreadNew(&HPTask, (void*) 50, &HPTaskAttr);  // Create HPTask
  osThreadNew(&LPTask, (void*)200, &LPTaskAttr);  // Create LPTask
  osKernelStart();                                // Start embOS
  return 0;
}

/*************************** End of file ****************************/
